@@ -26,7 +26,7 @@ macro_rules! error_shim {
         /// # Examples
         /// ```
         /// use human_errors;
-        /// 
+        ///
         /// human_errors::user(
         ///   "We could not open the config file you provided.",
         ///   "Make sure that the file exists and is readable by the application.",
@@ -48,7 +48,7 @@ macro_rules! error_shim {
         /// # Examples
         /// ```
         /// use human_errors;
-        /// 
+        ///
         /// human_errors::user_with_cause(
         ///   "We could not open the config file you provided.",
         ///   "Make sure that you've specified a valid config file with the --config option.",
@@ -75,7 +75,7 @@ macro_rules! error_shim {
         /// # Examples
         /// ```
         /// use human_errors;
-        /// 
+        ///
         /// human_errors::user_with_internal(
         ///   "We could not open the config file you provided.",
         ///   "Make sure that the file exists and is readable by the application.",
@@ -99,7 +99,7 @@ macro_rules! error_shim {
         /// # Examples
         /// ```
         /// use human_errors;
-        /// 
+        ///
         /// human_errors::system(
         ///   "We could not open the config file you provided.",
         ///   "Make sure that the file exists and is readable by the application."
@@ -121,7 +121,7 @@ macro_rules! error_shim {
         /// # Examples
         /// ```
         /// use human_errors;
-        /// 
+        ///
         /// human_errors::system_with_cause(
         ///   "We could not open the config file you provided.",
         ///   "Make sure that you've specified a valid config file with the --config option.",
@@ -148,7 +148,7 @@ macro_rules! error_shim {
         /// # Examples
         /// ```
         /// use human_errors;
-        /// 
+        ///
         /// human_errors::system_with_internal(
         ///   "We could not open the config file you provided.",
         ///   "Make sure that the file exists and is readable by the application.",
@@ -190,6 +190,7 @@ macro_rules! error_shim {
             }
         }
 
+        #[allow(clippy::from_over_into)]
         impl Into<$crate::Error> for $type {
             fn into(self) -> $crate::Error {
                 self.0
@@ -206,7 +207,7 @@ macro_rules! error_shim {
             /// # Examples
             /// ```
             /// use human_errors;
-            /// 
+            ///
             /// let err = human_errors::user(
             ///   "We could not open the config file you provided.",
             ///   "Make sure that the file exists and is readable by the application.",
@@ -310,7 +311,7 @@ macro_rules! error_shim {
                 self.0.fmt(f)
             }
         }
-    }
+    };
 }
 
 #[cfg(test)]
@@ -329,11 +330,8 @@ mod tests {
 
     #[test]
     fn test_error_conversion() {
-        let err = user(
-            "Something exploded.",
-            "Don't blow it up in future."
-        );
+        let err = user("Something exploded.", "Don't blow it up in future.");
 
         assert_eq!(err.description(), "Something exploded.");
     }
-}
\ No newline at end of file
+}
